<?php
/**
 * Show pagesets
 *
 * This file is part of Zoph.
 *
 * Zoph is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Zoph is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with Zoph; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @package Zoph
 * @author Jeroen Roos
 */
require_once "include.inc.php";

$title=translate("Pagesets");
require_once "header.inc.php";
?>
<h1>
<?php
if ($user->isAdmin()) {
    ?>
    <ul class="actionlink">
      <li><a href="pageset.php?_action=new"><?php echo translate("new") ?></a></li>
    </ul>
    <?php
}
?>
<?php echo $title ?>
</h1>
<div class="main">
  <br>
  <?php echo pageset::getTable() ?>
  <br>
</div>
<?php
require_once "footer.inc.php";
?>
